#
# spec file for package ghc-transformers-compat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name transformers-compat
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.7.2
Release:        bp160.1.7
Summary:        A small compatibility shim for the transformers library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
This package includes backported versions of types that were added to
transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
transformers 0.2 or 0.3 compatibility to run on old versions of the platform,
but also need those types.

Those users should be able to just depend on 'transformers >= 0.2' and
'transformers-compat >= 0.3'.

Note: missing methods are not supplied, but this at least permits the types to
be used.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jun 26 2022 Peter Simons <psimons@suse.com>
- Update transformers-compat to version 0.7.2.
  0.7.2 [2022.06.26]
  - -----------------
  * Add `Eq`, `Ord`, `Read`, and `Show` instances for `FunctorClassesDefault` in
    `Data.Functor.Classes.Generic`.
* Mon Jan 10 2022 Peter Simons <psimons@suse.com>
- Update transformers-compat to version 0.7.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update transformers-compat to version 0.7.1.
  0.7.1 [2021.10.30]
  - -----------------
  * Backport new instances from GHC 9.2/`base-4.16`
  * `Eq1`, `Read1`, and `Show1` instances for `Complex`
  * `Eq{1,2}`, `Ord{1,2}`, `Show{1,2}`, and `Read{1,2}` instances for `(,,)`
    and `(,,,)`
* Tue Jul 27 2021 psimons@suse.com
- Update transformers-compat to version 0.7.
  0.7 [2021.07.25]
  - ---------------
  * Backport changes from `transformers-0.6.*`:
  * Remove the long-deprecated `selectToCont` function from
    `Control.Monad.Trans.Select`.
  * Backport various `Generic`, `Generic1`, and `Data` instances.
  * Backport `handleE`, `tryE`, and `finallyE` to `Control.Monad.Trans.Except`.
  * Backport explicit implementations of `(<$)`, `liftA2`, `(*>)`, and `(<*)`
    for `Control.Applicative.Backwards`.
  * Backport a lazier implementation of `(<*>)` for `Control.Applicative.Lift`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update transformers-compat to version 0.6.6.
  0.6.6 [2020.09.30]
  - -----------------
  * Add `FunctorClassesDefault`, an adapter newtype suitable for `DerivingVia`,
    to `Data.Functor.Classes.Generic`.
  * Fix a bug in which `readsPrec1Default`/`liftReadsPrecDefault` would parse
    empty data types too strictly.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun May 12 2019 psimons@suse.com
- Update transformers-compat to version 0.6.5.
  0.6.5 [2019.05.11]
  - -----------------
  * Ensure that the backported `MonadFail` instance for `ExceptT` is available
    when built against `transformers-0.4.*`.
* Wed Apr  3 2019 psimons@suse.com
- Update transformers-compat to version 0.6.4.
  0.6.4 [2019.04.01]
  - -----------------
  * Use more conservative CPP to guard the backported `MonadFix` instance for
    `ListT`.
* Tue Apr  2 2019 psimons@suse.com
- Update transformers-compat to version 0.6.3.
  0.6.3 [2019.04.01]
  - -----------------
  * Backport changes from `transformers-0.5.6.*`:
  * Backport the `MonadFix` instance for `ListT` in
    `Control.Monad.Trans.Instances`.
  * Generalize the type of `except` in `Control.Monad.Trans.Except`.
  * Backport `MonadFail` instances for `AccumT`, `Reverse`, and `SelectT` on
    pre-8.0 versions of GHC by depending on the `fail` package if necessary.
  * Backport `MonadFail` instances for monad transformer types in
    `Control.Monad.Trans.Instances`.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update transformers-compat to version 0.6.2.
  * `transformers-compat` now uses automatic flags instead of manual ones.
    This has a number of benefits:
  * There is no need for making several simultaneous releases to support each
    flag combination.
  * As a result, the `cabal-install` constraint solver should have a much
    easier time figuring out install-plans involving `transformers-compat`.
    Due to old `cabal-install` bugs, `cabal-install-1.16` and older may have a
    harder time installing this package, so it is recommended that you use
    `cabal-install-1.18` or later. (Or, if you must use `cabal-install-1.16` or
    older, installing `transformers-compat` with the appropriate flags should
    help.)
  * Fix an oversight in which the `Control.Monad.Trans.Accum` and
    `Control.Monad.Trans.Select` modules were not backported when built with the
    `-ffour` flag.
  * Introduce the `Data.Functor.Classes.Generic` module, which provides functions that can generically implement methods in the `Eq1`, `Ord1`, `Read1`, and `Show1` classes (without the usual boilerplate involved).
  * Introduce the `generic-deriving` flag. When enabled, `transformers-compat` will depend on the `generic-deriving` library on older versions of GHC to backport `GHC.Generics` support for `Generic` instances and the machinery in `Data.Functor.Classes.Generic`.
  * Some instances were present in `Data.Functor.Sum` but not in `Control.Monad.Trans.Instances` (e.g., the `Generic`, `Typeable`, and `Data` instances for `Sum`). This has been fixed.
  * Backport changes from `transformers-0.5.5`:
  * Backport the `Semigroup` instance for `Constant`
  * Add `mapSelect` and `mapSelectT`
  * Define `selectToContT` (and deprecate `selectToCont` in favor of that)
  * Define some explicit `(*>)` definitions to avoid space leaks
  * Backport changes from `transformers-0.5.4` (i.e., add `Bifoldable` and `Bitraversable` instances for `Data.Functor.Constant`)
  * Backport changes from `transformers-0.5.3`:
  * Backport the `Control.Monad.Trans.Accum` and `Control.Monad.Trans.Select` modules
  * Backport the `eitherToErrors` and `elimLift` functions to `Control.Applicative.Lift`
  * Backport `Bits`, `FiniteBits`, `IsString`, `Num`, `Real`, `Integral`, `Fractional`, `Floating`, `RealFrac`, and `RealFloat` instances for `Data.Functor.Identity`
  * Backport `Monad`, `MonadFail`, and `MonadPlus` instances for `Data.Functor.Reverse`
  * Backport `Eq1`, `Ord1`, `Read1`, and `Show1` instances for `Data.Proxy`
  * Backport changes from `transformers-0.5.2` (i.e., add more `INLINE` annotations)
  * Backport changes from `transformers-0.5.1` (i.e., add `Bounded`, `Enum`, `Ix`, and `Storable` instances for `Identity`)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.5.1.4 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.0.4 revision 0 with cabal2obs.
* Wed May 13 2015 mimi.vx@gmail.com
- update to 0.4.0.4
* Tue Apr 21 2015 mimi.vx@gmail.com
- initial commit
